import { BasicEvent } from "@skeldjs/events";
import { AllGameSettings, GameSettings, SyncSettingsMessage } from "@skeldjs/protocol";
import { Hostable } from "../../Hostable";
import { PlayerData } from "../../PlayerData";
import { ProtocolEvent } from "../ProtocolEvent";
import { RoomEvent } from "../RoomEvent";
import { PlayerEvent } from "./PlayerEvent";
/**
 * Emitted when a player (i.e. the host of the room) sets the settings of the room.
 */
export declare class PlayerSyncSettingsEvent<RoomType extends Hostable = Hostable> extends BasicEvent implements RoomEvent, PlayerEvent, ProtocolEvent {
    readonly room: RoomType;
    readonly player: PlayerData<RoomType>;
    readonly message: SyncSettingsMessage | undefined;
    /**
     * The settings that were set.
     */
    readonly settings: GameSettings;
    static eventName: "player.syncsettings";
    eventName: "player.syncsettings";
    private _alteredSettings;
    private _isDirty;
    constructor(room: RoomType, player: PlayerData<RoomType>, message: SyncSettingsMessage | undefined, 
    /**
     * The settings that were set.
     */
    settings: GameSettings);
    /**
     * The altered settings of the room that will be set, if changeed.
     */
    get alteredSettings(): GameSettings;
    /**
     * Whether the {@link PlayerSyncSettingsEvent.alteredSettings} is different
     * from the {@link PlayerSyncSettingsEvent.settings}.
     */
    get isDirty(): boolean;
    /**
     * Change the settings that were set.
     * @param settings The settings to set.
     */
    setSettings(settings: Partial<AllGameSettings>): void;
}
