"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PlayerVoteArea = void 0;
const PlayerVoteState_1 = require("./PlayerVoteState");
class PlayerVoteArea {
    constructor(meetinghud, playerId, votedForId, didReport) {
        this.meetinghud = meetinghud;
        this.playerId = playerId;
        this.votedForId = votedForId;
        this.didReport = didReport;
    }
    get dirty() {
        return this.meetinghud.dirtyBit > 0;
    }
    set dirty(value) {
        if (value) {
            this.meetinghud.dirtyBit = 1;
        }
    }
    /**
     * The player that this vote state is for.
     */
    get player() {
        return this.meetinghud.room.getPlayerByPlayerId(this.playerId);
    }
    /**
     * Whether this player skipped voting.
     */
    get didSkip() {
        return this.votedForId === PlayerVoteState_1.VoteStateSpecialId.SkippedVote;
    }
    /**
     * Whether this player has either voted for a player or voted to skip.
     */
    get hasVoted() {
        return this.votedForId < PlayerVoteState_1.VoteStateSpecialId.IsDead ||
            this.votedForId === PlayerVoteState_1.VoteStateSpecialId.SkippedVote;
    }
    /**
     * The player that this player voted for, if any.
     */
    get votedFor() {
        if (this.votedForId >= PlayerVoteState_1.VoteStateSpecialId.IsDead)
            return undefined;
        return this.meetinghud.room.getPlayerByPlayerId(this.votedForId);
    }
    get canVote() {
        var _a;
        const playerInfo = (_a = this.player) === null || _a === void 0 ? void 0 : _a.info;
        return !(playerInfo === null || playerInfo === void 0 ? void 0 : playerInfo.isDead) && !(playerInfo === null || playerInfo === void 0 ? void 0 : playerInfo.isDisconnected);
    }
    static Deserialize(reader, meetinghud, playerId) {
        const votedForId = reader.uint8();
        const didReport = reader.bool();
        return new PlayerVoteArea(meetinghud, playerId, votedForId, didReport);
    }
    Serialize(writer) {
        writer.uint8(this.votedForId);
        writer.bool(this.didReport);
    }
    clearVote() {
        this.votedForId = PlayerVoteState_1.VoteStateSpecialId.NotVoted;
        this.dirty = true;
    }
    setSkipped() {
        this.votedForId = PlayerVoteState_1.VoteStateSpecialId.SkippedVote;
        this.dirty = true;
    }
    setSuspect(playerId) {
        if (playerId >= 252) {
            throw new RangeError("Suspect player ID cannot be greater than 252.");
        }
        this.votedForId = playerId;
        this.dirty = true;
    }
    setMissed() {
        this.votedForId = PlayerVoteState_1.VoteStateSpecialId.MissedVote;
        this.dirty = true;
    }
}
exports.PlayerVoteArea = PlayerVoteArea;
//# sourceMappingURL=PlayerVoteArea.js.map