import { HazelReader, HazelWriter } from "@skeldjs/util";
import { SystemType } from "@skeldjs/constant";
import { ExtractEventTypes } from "@skeldjs/events";
import { InnerShipStatus } from "../objects";
import { SystemStatus } from "./SystemStatus";
import { AutoOpenDoor } from "../misc/AutoOpenDoor";
import { DoorEvents } from "../misc/Door";
import { SystemStatusEvents } from "./events";
import { Hostable } from "../Hostable";
export interface AutoDoorsSystemData {
    dirtyBit: number;
    doors: boolean[];
}
export declare type AutoDoorsSystemEvents<RoomType extends Hostable = Hostable> = SystemStatusEvents & DoorEvents<RoomType> & ExtractEventTypes<[]>;
/**
 * Represents a system for doors that open after a period of time.
 *
 * See {@link AutoDoorsSystemEvents} for events to listen to.
 */
export declare class AutoDoorsSystem<RoomType extends Hostable = Hostable> extends SystemStatus<AutoDoorsSystemData, AutoDoorsSystemEvents, RoomType> {
    /**
     * The dirty doors to be updated on the next fixed update.
     */
    dirtyBit: number;
    /**
     * The doors in the map.
     */
    doors: AutoOpenDoor<RoomType>[];
    constructor(ship: InnerShipStatus<RoomType>, systemType: SystemType, data?: HazelReader | AutoDoorsSystemData);
    Deserialize(reader: HazelReader, spawn: boolean): void;
    Serialize(writer: HazelWriter, spawn: boolean): void;
    private _openDoor;
    /**
     * Open a door by its ID. This is a host operation on official servers.
     * @param doorId The ID of the door to open.
     */
    openDoor(doorId: number): Promise<void>;
    private _closeDoor;
    /**
     * Close a door by its ID. This is a host operation on official servers.
     * @param doorId The ID of the door to close.
     */
    closeDoor(doorId: number): Promise<void>;
    Detoriorate(delta: number): void;
}
