import { HazelReader, HazelWriter } from "@skeldjs/util";
import { SystemType } from "@skeldjs/constant";
import { RepairSystemMessage } from "@skeldjs/protocol";
import { ExtractEventTypes } from "@skeldjs/events";
import { InnerShipStatus } from "../objects";
import { SystemStatus } from "./SystemStatus";
import { PlayerData } from "../PlayerData";
import { SecurityCameraJoinEvent, SecurityCameraLeaveEvent } from "../events";
import { SystemStatusEvents } from "./events";
import { Hostable } from "../Hostable";
export interface SecurityCameraSystemData {
    players: Set<PlayerData>;
}
export declare type SecurityCameraSystemEvents<RoomType extends Hostable = Hostable> = SystemStatusEvents<RoomType> & ExtractEventTypes<[SecurityCameraJoinEvent<RoomType>, SecurityCameraLeaveEvent<RoomType>]>;
/**
 * Represents a system responsible for handling players entering and leaving security cameras.
 *
 * See {@link SecurityCameraSystemEvents} for events to listen to.
 */
export declare class SecurityCameraSystem<RoomType extends Hostable = Hostable> extends SystemStatus<SecurityCameraSystemData, SecurityCameraSystemEvents, RoomType> implements SecurityCameraSystemData {
    /**
     * The players currently looking at cameras.
     */
    players: Set<PlayerData>;
    constructor(ship: InnerShipStatus<RoomType>, systemType: SystemType, data?: HazelReader | SecurityCameraSystemData);
    Deserialize(reader: HazelReader, spawn: boolean): void;
    Serialize(writer: HazelWriter, spawn: boolean): void;
    private _addPlayer;
    /**
     * Add a player to the security cameras.
     * @param player The player to add.
     * @example
     *```typescript
     * security.addPlayer(client.me);
     * ```
     */
    addPlayer(player: PlayerData): Promise<void>;
    join(): Promise<void>;
    private _removePlayer;
    /**
     * Remove a player from the security cameras.
     * @param player The player to remove.
     * @example
     *```typescript
     * security.removePlayer(client.me);
     * ```
     */
    removePlayer(player: PlayerData): Promise<void>;
    leave(): Promise<void>;
    HandleRepair(player: PlayerData<RoomType> | undefined, amount: number, rpc: RepairSystemMessage | undefined): Promise<void>;
}
